@@ -12,13 +12,32 @@ import os
 import pmb.parse
 
 
+def _find_apkbuilds(args):
+    # Try to get a cached result first (we assume, that the aports don't change
+    # in one pmbootstrap call)
+    apkbuilds = args.cache.get("pmb.helpers.pmaports.apkbuilds")
+    if apkbuilds is not None:
+        return apkbuilds
+
+    apkbuilds = {}
+    for apkbuild in glob.iglob(f"{args.aports}/**/*/APKBUILD", recursive=True):
+        package = os.path.basename(os.path.dirname(apkbuild))
+        if package in apkbuilds:
+            raise RuntimeError(f"Package {package} found in multiple aports "
+                               "subfolders. Please put it only in one folder.")
+        apkbuilds[package] = apkbuild
+
+    # Sort dictionary so we don't need to do it over and over again in get_list()
+    apkbuilds = dict(sorted(apkbuilds.items()))
+
+    # Save result in cache
+    args.cache["pmb.helpers.pmaports.apkbuilds"] = apkbuilds
+    return apkbuilds
+
+
 def get_list(args):
     """ :returns: list of all pmaport pkgnames (["hello-world", ...]) """
-    ret = []
-    for apkbuild in glob.glob(args.aports + "/*/*/APKBUILD"):
-        ret.append(os.path.basename(os.path.dirname(apkbuild)))
-    ret.sort()
-    return ret
+    return list(_find_apkbuilds(args).keys())
 
 
 def guess_main_dev(args, subpkgname):
@@ -31,15 +50,15 @@ def guess_main_dev(args, subpkgname):
     :returns: full path to the pmaport or None
     """
     pkgname = subpkgname[:-4]
-    paths = glob.glob(args.aports + "/*/" + pkgname)
-    if paths:
-        logging.debug(subpkgname + ": guessed to be a subpackage of " +
-                      pkgname + " (just removed '-dev')")
-        return paths[0]
+    path = _find_apkbuilds(args).get(pkgname)
+    if path:
+        logging.verbose(subpkgname + ": guessed to be a subpackage of " +
+                        pkgname + " (just removed '-dev')")
+        return os.path.dirname(path)
 
-    logging.debug(subpkgname + ": guessed to be a subpackage of " + pkgname +
-                  ", which we can't find in pmaports, so it's probably in"
-                  " Alpine")
+    logging.verbose(subpkgname + ": guessed to be a subpackage of " + pkgname +
+                    ", which we can't find in pmaports, so it's probably in"
+                    " Alpine")
     return None
 
 
@@ -73,11 +92,11 @@ def guess_main(args, subpkgname):
         pkgname = "-".join(words)
 
         # Look in pmaports
-        paths = glob.glob(args.aports + "/*/" + pkgname)
-        if paths:
-            logging.debug(subpkgname + ": guessed to be a subpackage of " +
-                          pkgname)
-            return paths[0]
+        path = _find_apkbuilds(args).get(pkgname)
+        if path:
+            logging.verbose(subpkgname + ": guessed to be a subpackage of " +
+                            pkgname)
+            return os.path.dirname(path)
 
 
 def find(args, package, must_exist=True):
@@ -99,24 +118,19 @@ def find(args, package, must_exist=True):
             raise RuntimeError("Invalid pkgname: " + package)
 
         # Search in packages
-        paths = glob.glob(args.aports + "/*/" + package)
-        if len(paths) > 1:
-            raise RuntimeError("Package " + package + " found in multiple"
-                               " aports subfolders. Please put it only in one"
-                               " folder.")
-        elif len(paths) == 1:
-            ret = paths[0]
+        path = _find_apkbuilds(args).get(package)
+        if path:
+            ret = os.path.dirname(path)
 
         # Search in subpackages and provides
         if not ret:
-            for path_current in glob.glob(args.aports + "/*/*/APKBUILD"):
+            for path_current in _find_apkbuilds(args).values():
                 apkbuild = pmb.parse.apkbuild(args, path_current)
                 found = False
 
                 # Subpackages
                 if package in apkbuild["subpackages"]:
                     found = True
-                    break
 
                 # Provides (cut off before equals sign for entries like
                 # "mkbootimg=0.0.1")
