@@ -11,6 +11,7 @@ import pmb.chroot.apk
 import pmb.chroot.other
 import pmb.chroot.initfs
 import pmb.config
+import pmb.helpers.devices
 import pmb.helpers.run
 import pmb.install.blockdevice
 import pmb.install.file
@@ -62,8 +63,7 @@ def get_nonfree_packages(args, device):
               ["device-nokia-n900-nonfree-firmware"]
     """
     # Read subpackages
-    apkbuild_path = args.aports + "/device/device-" + device + "/APKBUILD"
-    apkbuild = pmb.parse.apkbuild(args, apkbuild_path)
+    apkbuild = pmb.parse.apkbuild(args, pmb.helpers.devices.find_path(args, device, 'APKBUILD'))
     subpackages = apkbuild["subpackages"]
 
     # Check for firmware and userland
@@ -362,11 +362,13 @@ def embed_firmware(args):
 
 def sanity_check_sdcard(device):
     device_name = os.path.basename(device)
+    if not os.path.exists(device):
+        raise RuntimeError("{} doesn't exist, is the sdcard plugged?".format(device))
     if os.path.isdir('/sys/class/block/{}'.format(device_name)):
         with open('/sys/class/block/{}/ro'.format(device_name), 'r') as handle:
             ro = handle.read()
         if ro == '1\n':
-            raise RuntimeError("{} is read-only, Is the sdcard locked?".format(device))
+            raise RuntimeError("{} is read-only, is the sdcard locked?".format(device))
 
 
 def install_system_image(args):
@@ -440,6 +442,11 @@ def install_system_image(args):
                          " /boot and / subpartitions. That way we don't need to"
                          " change the partition layout on your device.)")
 
+    # if current flasher supports vbmeta and partition is explicitly spcified in deviceinfo
+    if "flash_vbmeta" in flasher_actions and args.deviceinfo["flash_fastboot_partition_vbmeta"]:
+        logging.info("* pmbootstrap flasher flash_vbmeta")
+        logging.info("  Flashes vbmeta image with verification disabled flag.")
+
     # Most flash methods operate independently of the boot partition.
     # (e.g. an Android boot image is generated). In that case, "flash_kernel"
     # works even when partitions are split or installing for sdcard.
@@ -513,8 +520,6 @@ def install(args):
         install_packages += args.extra_packages.split(",")
     if args.add:
         install_packages += args.add.split(",")
-    if args.device.startswith("qemu-"):
-        install_packages += ["mesa-" + args.qemu_native_mesa_driver]
     for pkgname in install_packages:
         pmb.build.package(args, pkgname, args.deviceinfo["arch"])
 
