@@ -70,6 +70,15 @@ def arguments_flasher(subparser):
                                    " 'userdata' on Android may have more"
                                    " space)")
 
+    # Flash vbmeta
+    flash_vbmeta = sub.add_parser("flash_vbmeta",
+                                  help="generate and flash AVB 2.0 image with disable"
+                                       " verification flag set to a partition on the"
+                                       " device (typically called vbmeta)")
+    flash_vbmeta.add_argument("--partition", default=None,
+                              help="partition to flash the vbmeta to (defaults"
+                                   " to deviceinfo_flash_*_partition_vbmeta")
+
     # Actions without extra arguments
     sub.add_parser("sideload", help="sideload recovery zip")
     sub.add_parser("list_flavors", help="list installed kernel flavors" +
@@ -114,26 +123,40 @@ def arguments_initfs(subparser):
 
 def arguments_qemu(subparser):
     ret = subparser.add_parser("qemu")
-    ret.add_argument("--arch", choices=["aarch64", "arm", "x86_64"],
-                     help="emulate a different architecture")
     ret.add_argument("--cmdline", help="override kernel commandline")
-    ret.add_argument(
-        "--image-size", help="set rootfs size (e.g. 2048M or 2G)")
+    ret.add_argument("--image-size", default="4G",
+                     help="set rootfs size, e.g. 2048M or 2G (default: 4G)")
     ret.add_argument("-m", "--memory", type=int, default=1024,
                      help="guest RAM (default: 1024)")
     ret.add_argument("-p", "--port", type=int, default=2222,
                      help="SSH port (default: 2222)")
-    ret.add_argument("--flavor", help="name of the kernel flavor (run 'pmbootstrap flasher list_flavors'"
-                     " to get a list of all installed flavors")
 
-    display = ret.add_mutually_exclusive_group()
-    display.add_argument("--spice", dest="spice_port", const="8077",
-                         action="store", nargs="?", default=None,
-                         help="use SPICE for 2D acceleration (default port:"
-                         " 8077)")
-    display.add_argument("--display", dest="qemu_display", const="sdl,gl=on",
-                         help="QEMU's display parameter (default: sdl,gl=on)",
-                         default="sdl,gl=on", nargs="?")
+    ret.add_argument("--no-kvm", dest="qemu_kvm", default=True, action='store_false',
+                     help="Avoid using hardware-assisted virtualization with KVM "
+                     "even when available (SLOW!)")
+    ret.add_argument("--cpu", dest="qemu_cpu",
+                     help="Override emulated QEMU CPU. By default, the host CPU "
+                     "will be emulated when using KVM and the QEMU default otherwise "
+                     "(usually a CPU with minimal features). "
+                     "A useful value is 'max' (emulate all features that are available), "
+                     "use --cpu help to get a list of possible values from QEMU.")
+
+    ret.add_argument("--tablet", dest="qemu_tablet", action='store_true',
+                     default=False, help="Use 'tablet' instead of 'mouse' input "
+                     "for QEMU. The tablet input device automatically grabs/releases "
+                     "the mouse when moving in/out of the QEMU window. "
+                     "(Note: For some reason the mouse position is not reported "
+                     "correctly with this in some cases...)")
+
+    ret.add_argument("--display", dest="qemu_display", choices=["sdl", "gtk", "none"],
+                     help="QEMU's display parameter (default: sdl,gl=on)",
+                     default="sdl", nargs="?")
+    ret.add_argument("--no-gl", dest="qemu_gl", default=True, action='store_false',
+                     help="Avoid using GL for accelerating graphics in QEMU "
+                     "(use software rasterizer, slow!)")
+    ret.add_argument("--video", dest="qemu_video", default="1024x768@60",
+                     help="Video resolution for QEMU (WidthxHeight@RefreshRate). "
+                     "Default is 1024x768@60.")
 
     ret.add_argument("--audio", dest="qemu_audio", choices=["alsa", "pa", "sdl"],
                      help="QEMU's audio backend (default: none)",
@@ -286,6 +309,7 @@ def package_completer(prefix, action, parser, parsed_args):
     args = parsed_args
     pmb.config.merge_with_args(args)
     pmb.helpers.args.replace_placeholders(args)
+    pmb.helpers.args.add_cache(args)
     packages = set(
         package for package in pmb.helpers.pmaports.get_list(args)
         if package.startswith(prefix))
