@@ -13,26 +13,20 @@ import pmb.chroot.apk
 import pmb.chroot.other
 import pmb.chroot.initfs
 import pmb.config
-import pmb.helpers.devices
 import pmb.helpers.run
 import pmb.parse.arch
 
 
-def system_image(args, device):
+def system_image(args):
     """
     Returns path to rootfs for specified device. In case that it doesn't
     exist, raise and exception explaining how to generate it.
     """
-    path = args.work + "/chroot_native/home/pmos/rootfs/" + device + ".img"
+    path = args.work + "/chroot_native/home/pmos/rootfs/" + args.device + ".img"
     if not os.path.exists(path):
         logging.debug("Could not find rootfs: " + path)
-        img_command = "pmbootstrap install"
-        if device != args.device:
-            img_command = ("pmbootstrap config device " + device +
-                           "' and '" + img_command)
-        message = "The rootfs '{0}' has not been generated yet, please" \
-                  " run '{1}' first.".format(device, img_command)
-        raise RuntimeError(message)
+        raise RuntimeError("The rootfs has not been generated yet, please "
+                           "run 'pmbootstrap install' first.")
     return path
 
 
@@ -49,19 +43,6 @@ def which_qemu(args, arch):
                            " run qemu.")
 
 
-def command_spice(args):
-    """
-    Generate the full SPICE command with arguments connect to the virtual
-    machine
-    :returns: None or list with the spice command, e.g.:
-              ["spicy", "-h", "127.0.0.1", "-p", "8077"]
-    """
-    if not args.spice_port:
-        return None
-
-    return ["remote-viewer", "spice://127.0.0.1?port=" + args.spice_port]
-
-
 def create_gdk_loader_cache(args):
     """
     Create a gdk loader cache that can be used for running GTK UIs outside of
@@ -85,25 +66,24 @@ def create_gdk_loader_cache(args):
     return rootfs_native + custom_cache_path
 
 
-def command_qemu(args, arch, device, img_path, spice_enabled):
+def command_qemu(args, arch, img_path):
     """
     Generate the full qemu command with arguments to run postmarketOS
     """
-    deviceinfo = pmb.parse.deviceinfo(args, device=device)
-    cmdline = deviceinfo["kernel_cmdline"]
+    cmdline = args.deviceinfo["kernel_cmdline"]
     if args.cmdline:
         cmdline = args.cmdline
+
+    if "video=" not in cmdline:
+        cmdline += " video=" + args.qemu_video
+
     logging.debug("Kernel cmdline: " + cmdline)
 
     port_ssh = str(args.port)
-    port_telnet = str(args.port + 1)
 
-    suffix = "rootfs_" + device
+    suffix = "rootfs_" + args.device
     rootfs = args.work + "/chroot_" + suffix
-    if args.flavor:
-        flavor = args.flavor
-    else:
-        flavor = pmb.chroot.other.kernel_flavors_installed(args, suffix)[0]
+    flavor = pmb.chroot.other.kernel_flavors_installed(args, suffix)[0]
 
     if args.host_qemu:
         qemu_bin = which_qemu(args, arch)
@@ -130,75 +110,52 @@ def command_qemu(args, arch, device, img_path, spice_enabled):
         command += [rootfs_native + "/usr/bin/qemu-system-" + arch]
         command += ["-L", rootfs_native + "/usr/share/qemu/"]
 
+    command += ["-nodefaults"]
     command += ["-kernel", rootfs + "/boot/vmlinuz-" + flavor]
     command += ["-initrd", rootfs + "/boot/initramfs-" + flavor]
     command += ["-append", shlex.quote(cmdline)]
+
+    command += ["-smp", str(os.cpu_count())]
     command += ["-m", str(args.memory)]
-    command += ["-netdev",
-                "user,id=net0,"
+
+    command += ["-serial", "stdio"]
+    command += ["-drive", "file=" + img_path + ",format=raw,if=virtio"]
+    if args.qemu_tablet:
+        command += ["-device", "virtio-tablet-pci"]
+    else:
+        command += ["-device", "virtio-mouse-pci"]
+    command += ["-device", "virtio-keyboard-pci"]
+    command += ["-nic",
+                "user,model=virtio-net-pci,"
                 "hostfwd=tcp::" + port_ssh + "-:22,"
-                "hostfwd=tcp::" + port_telnet + "-:23"
-                ",net=172.16.42.0/24,dhcpstart=" + pmb.config.default_ip
                 ]
-    command += ["-show-cursor"]
-
-    if deviceinfo["dtb"] != "":
-        dtb_image = rootfs + "/usr/share/dtb/" + deviceinfo["dtb"] + ".dtb"
-        if not os.path.exists(dtb_image):
-            raise RuntimeError("DTB file not found: " + dtb_image)
-        command += ["-dtb", dtb_image]
-
-    smp = os.cpu_count()
 
     if arch == "x86_64":
-        command += ["-serial", "stdio"]
-        command += ["-drive", "file=" + img_path + ",format=raw"]
-        command += ["-device", "e1000,netdev=net0"]
-
-    elif arch == "arm":
-        command += ["-M", "vexpress-a9"]
-        command += ["-sd", img_path]
-        command += ["-device", "virtio-net-device,netdev=net0"]
-        smp = min(smp, 4)
-
+        command += ["-vga", "virtio"]
     elif arch == "aarch64":
         command += ["-M", "virt"]
         command += ["-cpu", "cortex-a57"]
         command += ["-device", "virtio-gpu-pci"]
-        command += ["-device", "virtio-net-device,netdev=net0"]
-        command += ["-usb", "-device", "usb-ehci",
-                    "-device", "usb-kbd", "-device", "usb-mouse"]
-
-        # Add storage
-        command += ["-device", "virtio-blk-device,drive=system"]
-        command += ["-drive", "if=none,id=system,file={},id=hd0".format(img_path)]
-
     else:
         raise RuntimeError("Architecture {} not supported by this command yet.".format(arch))
 
-    command += ["-smp", str(smp)]
-
     # Kernel Virtual Machine (KVM) support
-    native = True
-    if args.arch:
-        arch1 = pmb.parse.arch.uname_to_qemu(args.arch_native)
-        arch2 = pmb.parse.arch.uname_to_qemu(args.arch)
-        native = (arch1 == arch2)
-    if native and os.path.exists("/dev/kvm"):
+    native = args.arch_native == args.deviceinfo["arch"]
+    if args.qemu_kvm and native and os.path.exists("/dev/kvm"):
         command += ["-enable-kvm"]
+        command += ["-cpu", "host"]
     else:
         logging.info("WARNING: QEMU is not using KVM and will run slower!")
 
-    # 2D acceleration support via QXL/SPICE or virtio
-    if spice_enabled:
-        command += ["-vga", "qxl"]
-        command += ["-spice",
-                    "port=" + args.spice_port + ",addr=127.0.0.1" +
-                    ",disable-ticketing"]
-    else:
-        if native and args.qemu_native_mesa_driver == "dri-virtio":
-            command += ["-vga", "virtio"]
-        command += ["-display", args.qemu_display]
+    if args.qemu_cpu:
+        command += ["-cpu", args.qemu_cpu]
+
+    display = args.qemu_display
+    if display != "none":
+        display += ",gl=" + ("on" if args.qemu_gl else "off")
+
+    command += ["-display", display]
+    command += ["-show-cursor"]
 
     # Audio support
     if args.qemu_audio:
@@ -257,8 +214,6 @@ def install_depends(args, arch):
     depends = ["qemu", "qemu-system-" + arch, "qemu-ui-sdl", "qemu-ui-gtk",
                "mesa-gl", "mesa-egl", "mesa-dri-classic", "mesa-dri-gallium",
                "qemu-audio-alsa", "qemu-audio-pa", "qemu-audio-sdl"]
-    if args.spice_port:
-        depends += ["virt-viewer", "font-noto"]
     pmb.chroot.apk.install(args, depends)
 
 
@@ -266,20 +221,18 @@ def run(args):
     """
     Run a postmarketOS image in qemu
     """
-    # Get arch, device, img_path
-    arch = pmb.parse.arch.uname_to_qemu(args.arch_native)
-    if args.arch:
-        arch = pmb.parse.arch.uname_to_qemu(args.arch)
-    device = pmb.parse.arch.qemu_to_pmos_device(arch)
-    img_path = system_image(args, device)
+    if not args.device.startswith("qemu-"):
+        raise RuntimeError("'pmbootstrap qemu' can be only used with one of "
+                           "the QEMU device packages. Run 'pmbootstrap init' "
+                           "and select the 'qemu' vendor.")
+    arch = pmb.parse.arch.alpine_to_qemu(args.deviceinfo["arch"])
+
+    img_path = system_image(args)
     if not args.host_qemu:
         install_depends(args, arch)
     logging.info("Running postmarketOS in QEMU VM (" + arch + ")")
 
-    # Get the QEMU and spice commands
-    spice = command_spice(args)
-    spice_enabled = True if spice else False
-    qemu, env = command_qemu(args, arch, device, img_path, spice_enabled)
+    qemu, env = command_qemu(args, arch, img_path)
 
     # Workaround: QEMU runs as local user and needs write permissions in the
     # rootfs, which is owned by root
@@ -293,23 +246,16 @@ def run(args):
         logging.info("NOTE: Run 'pmbootstrap qemu --image-size 2G' to set"
                      " the rootfs size when you run out of space!")
 
-    # SSH/telnet hints
-    logging.info("Connect to the VM (telnet requires 'pmbootstrap initfs"
-                 " hook_add debug-shell'):")
+    # SSH/serial hints
+    logging.info("Connect to the VM:")
     logging.info("* (ssh) ssh -p {port} {user}@localhost".format(**vars(args)))
-    logging.info("* (telnet) telnet localhost " + str(args.port + 1))
+    logging.info("* (serial) in this console (stdout/stdin)")
 
-    # Run QEMU (or QEMU + SPICE) and kill it together with pmbootstrap
+    # Run QEMU and kill it together with pmbootstrap
     process = None
     try:
         signal.signal(signal.SIGTERM, sigterm_handler)
-        output = "background" if spice_enabled else "interactive"
-        process = pmb.helpers.run.user(args, qemu, output=output, env=env)
-        if spice:
-            pmb.chroot.other.copy_xauthority(args)
-            pmb.chroot.user(args, spice, "native", output="tui",
-                            env={"DISPLAY": os.environ.get("DISPLAY"),
-                                 "XAUTHORITY": "/home/pmos/.Xauthority"})
+        process = pmb.helpers.run.user(args, qemu, output="tui", env=env)
     except KeyboardInterrupt:
         # Don't show a trace when pressing ^C
         pass
