@@ -77,11 +77,11 @@ def setup_work(args, tmpdir):
             pmb.helpers.run.user(args, ["ln", "-s", path, tmpdir + "/"])
 
     # Copy testdata and selected device aport
-    for folder in ["device", "main"]:
+    for folder in ["device/testing", "main"]:
         pmb.helpers.run.user(args, ["mkdir", "-p", args.aports, tmpdir +
                                     "/_aports/" + folder])
-    pmb.helpers.run.user(args, ["cp", "-r", args.aports + "/device/device-" +
-                                args.device, tmpdir + "/_aports/device"])
+    pmb.helpers.run.user(args, ["cp", "-r", args.aports + "/device/testing/device-" +
+                                args.device, tmpdir + "/_aports/device/testing"])
     for pkgname in ["testlib", "testapp", "testsubpkg"]:
         pmb.helpers.run.user(args, ["cp", "-r",
                                     "test/testdata/pkgrel_bump/aports/" + pkgname,
